import type { CreateRunner } from '../models/CreateRunner';
import type { ResponseEmpty } from '../models/ResponseEmpty';
import type { ResponseRunner } from '../models/ResponseRunner';
import type { ResponseScan } from '../models/ResponseScan';
import type { ResponseTrackScan } from '../models/ResponseTrackScan';
import type { RunnerGroupNeededError } from '../models/RunnerGroupNeededError';
import type { RunnerGroupNotFoundError } from '../models/RunnerGroupNotFoundError';
import type { UpdateRunner } from '../models/UpdateRunner';
export declare class RunnerService {
    /**
     * Get all
     * Lists all runners from all teams/orgs. <br> This includes the runner's group and distance ran.
     * @returns ResponseRunner
     * @throws ApiError
     */
    static runnerControllerGetAll(): Promise<Array<ResponseRunner>>;
    /**
     * Post
     * Create a new runner. <br> Please remeber to provide the runner's group's id.
     * @param requestBody CreateRunner
     * @returns any
     * @throws ApiError
     */
    static runnerControllerPost(requestBody?: CreateRunner): Promise<(ResponseRunner | RunnerGroupNeededError | RunnerGroupNotFoundError)>;
    /**
     * Get one
     * Lists all information about the runner whose id got provided.
     * @param id
     * @returns ResponseRunner
     * @throws ApiError
     */
    static runnerControllerGetOne(id: number): Promise<ResponseRunner>;
    /**
     * Put
     * Update the runner whose id you provided. <br> Please remember that ids can't be changed.
     * @param id
     * @param requestBody UpdateRunner
     * @returns ResponseRunner
     * @throws ApiError
     */
    static runnerControllerPut(id: number, requestBody?: UpdateRunner): Promise<ResponseRunner>;
    /**
     * Remove
     * Delete the runner whose id you provided. <br> This will also delete all scans and cards associated with the runner. <br> If no runner with this id exists it will just return 204(no content).
     * @param id
     * @param force
     * @returns ResponseRunner
     * @returns ResponseEmpty
     * @throws ApiError
     */
    static runnerControllerRemove(id: number, force?: boolean): Promise<ResponseRunner | ResponseEmpty>;
    /**
     * Get scans
     * Lists all scans of the runner whose id got provided. <br> If you only want the valid scans just add the ?onlyValid=true query param.
     * @param id
     * @returns any
     * @throws ApiError
     */
    static runnerControllerGetScans(id: number): Promise<(Array<ResponseScan> | Array<ResponseTrackScan>)>;
}
